enum keyword {
	K_EXEC=1, K_MAXEXEC, K_VMAXEXEC, K_MAXQUEUE, K_PFACTOR,K_SUPERVISOR, K_MAIL, K_MAILSUPERVISOR,K_HOST,
	K_CONSOLE, K_NICE, K_RESTART, K_TIMECMD, K_DAY,
	K_OFF, K_DRAIN, K_ON, K_NUMBER, K_VARIABLE, K_LINE,
	K_TIMESTOP, K_TIMESCHED,
	K_SYNTAX, K_LOADSTOP, K_LOADSCHED,
	K_MINFREE,
	K_PROGRAM,
	K_RLIMITCPU,
	K_RLIMITFSIZE,
	K_RLIMITDATA,
	K_RLIMITSTACK,
	K_RLIMITCORE,
	K_RLIMITRSS,
	K_RLIMITNOFILE,
	K_RLIMITVMEM
};
